@@ -104,6 +104,7 @@ install_dialog_response (GtkWidget *widget, int response_id, gpointer data)
 	GList *src, *target;
 	GnomeVFSURI *src_uri;
 	const gchar *raw;
+	gboolean icon_theme;
 	
 	if (response_id == GTK_RESPONSE_HELP) {
 		capplet_help (GTK_WINDOW (widget),
@@ -113,6 +114,7 @@ install_dialog_response (GtkWidget *widget, int response_id, gpointer data)
 	}
 
 	if (response_id == 0) {
+		icon_theme = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "icon_theme"));
 		raw = gtk_entry_get_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (WID ("install_theme_picker")))));
 		if (raw == NULL || strlen (raw) <= 0)
 			return;
@@ -127,8 +129,10 @@ install_dialog_response (GtkWidget *widget, int response_id, gpointer data)
 		src_uri = gnome_vfs_uri_new (filename);
 		base = gnome_vfs_uri_extract_short_name (src_uri);
 		src = g_list_append (NULL, src_uri);
-		path = g_build_filename (g_get_home_dir (), ".themes",
-				         base, NULL);
+		if (icon_theme)
+			path = g_build_filename (g_get_home_dir (), ".icons", base, NULL);
+		else
+			path = g_build_filename (g_get_home_dir (), ".themes", base, NULL);
 		target = g_list_append (NULL, gnome_vfs_uri_new (path));
 		
 		dlg = file_transfer_dialog_new ();
@@ -151,7 +155,7 @@ install_dialog_response (GtkWidget *widget, int response_id, gpointer data)
 }
 
 void
-gnome_theme_installer_run (GtkWidget *parent, gchar *filename)
+gnome_theme_installer_run (GtkWidget *parent, gchar *filename, gboolean icon_theme)
 {
 	static gboolean running_theme_install = FALSE;
 	GladeXML *dialog;
@@ -165,8 +169,8 @@ gnome_theme_installer_run (GtkWidget *parent, gchar *filename)
 	dialog = glade_xml_new (GLADEDIR "/theme-install.glade", NULL, NULL);
 	widget = WID ("install_dialog");
 	
-	g_signal_connect (G_OBJECT (widget), "response",
-		G_CALLBACK (install_dialog_response), dialog);
+	g_object_set_data (G_OBJECT (widget), "icon_theme", GINT_TO_POINTER (icon_theme));
+	g_signal_connect (G_OBJECT (widget), "response", G_CALLBACK (install_dialog_response), dialog);
 	gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (parent));
 	gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ON_PARENT);
 	if (filename)
@@ -180,4 +184,3 @@ gnome_theme_installer_run (GtkWidget *parent, gchar *filename)
 
 	running_theme_install = FALSE;
 }
-
